@@ -39,7 +39,6 @@
 #include "indexedstring.h"
 #include "duchainregister.h"
 #include "persistentsymboltable.h"
-#include "repositories/stringrepository.h"
 #include "types/identifiedtype.h"
 #include "types/structuretype.h"
 #include "functiondefinition.h"
@@ -48,18 +47,13 @@
 #include "types/typeutils.h"
 #include "types/typealiastype.h"
 #include "classdeclaration.h"
+#include "repositories/stringrepository.h"
 
 using namespace KTextEditor;
 
 namespace KDevelop
 {
 
-///@todo Use reference counting
-static Repositories::StringRepository& commentRepository() {
-    static Repositories::StringRepository commentRepositoryObject("Comment Repository");
-    return commentRepositoryObject;
-}
-
 REGISTER_DUCHAIN_ITEM(Declaration);
 
 DeclarationData::DeclarationData()
@@ -84,6 +78,16 @@ m_isFinal(rhs.m_isFinal)
 {
 }
 
+///@todo Use reference counting
+static Repositories::StringRepository& commentRepository() {
+    static Repositories::StringRepository commentRepositoryObject("Comment Repository");
+    return commentRepositoryObject;
+}
+
+void initDeclarationRepositories() {
+  commentRepository();
+}
+
 Declaration::Kind Declaration::kind() const {
   DUCHAIN_D(Declaration);
   return d->m_kind;
