@@ -64,6 +64,7 @@
 #include <unistd.h>
 #include "waitforupdate.h"
 #include "referencecounting.h"
+#include "importers.h"
 
 Q_DECLARE_METATYPE(KDevelop::IndexedString)
 Q_DECLARE_METATYPE(KDevelop::IndexedTopDUContext)
@@ -1127,6 +1128,41 @@ DUChain* DUChain::self()
   return sdDUChainPrivate->instance;
 }
 
+extern void initModificationRevisionSetRepository();
+extern void initDeclarationRepositories();
+extern void initIdentifierRepository();
+extern void initTypeRepository();
+extern void initInstantiationInformationRepository();
+extern void initReferenceCounting();
+
+void DUChain::initialize()
+{
+  // Initialize the global item repository as first thing after loading the session
+  globalItemRepositoryRegistry();
+
+  initReferenceCounting();
+
+  // This needs to be initialized here too as the function is not threadsafe, but can
+  // sometimes be called from different threads. This results in the underlying QFile
+  // being 0 and hence crashes at some point later when accessing the contents via 
+  // read. See https://bugs.kde.org/show_bug.cgi?id=250779
+  RecursiveImportRepository::repository();
+  RecursiveImportCacheRepository::repository();
+
+  // similar to above, see https://bugs.kde.org/show_bug.cgi?id=255323
+  initDeclarationRepositories();
+
+  initModificationRevisionSetRepository();
+  initIdentifierRepository();
+  initTypeRepository();
+  initInstantiationInformationRepository();
+
+  Importers::self();
+ 
+  globalImportIdentifier();
+  globalAliasIdentifier();
+}
+
 DUChainLock* DUChain::lock()
 {
   return &sdDUChainPrivate->lock;
