@@ -20,10 +20,18 @@
 #include <KStandardDirs>
 #include <KDebug>
 
+#include "snippetfeatures.h"
+
+#ifdef SNIPPETS_HAVE_TPLIFACE2
+    #include <ktexteditor/editor.h>
+    #include <interfaces/ipartcontroller.h>
+    #include <ktexteditor/templateinterface2.h>
+#endif
+
 SnippetStore* SnippetStore::m_self = 0;
 
 SnippetStore::SnippetStore(SnippetPlugin* plugin)
-    : m_plugin(plugin)
+    : m_plugin(plugin), m_scriptregistrar(0)
 {
     m_self = this;
 
@@ -36,6 +44,10 @@ SnippetStore::SnippetStore(SnippetPlugin* plugin)
         SnippetRepository* repo = new SnippetRepository(file);
         appendRow(repo);
     }
+
+    #ifdef SNIPPETS_HAVE_TPLIFACE2
+    m_scriptregistrar = qobject_cast<KTextEditor::TemplateScriptRegistrar*>(KDevelop::ICore::self()->partController()->editorPart());
+    #endif
 }
 
 SnippetStore::~SnippetStore()
@@ -108,5 +120,28 @@ SnippetRepository* SnippetStore::repositoryForFile(const QString& file)
     return 0;
 }
 
+void SnippetStore::unregisterScript(KTextEditor::TemplateScript* script)
+{
+#ifdef SNIPPETS_HAVE_TPLIFACE2
+    if ( m_scriptregistrar ) {
+        m_scriptregistrar->unregisterTemplateScript(script);
+    }
+#else
+    Q_UNUSED(script);
+#endif
+}
+
+KTextEditor::TemplateScript* SnippetStore::registerScript(const QString& script)
+{
+#ifdef SNIPPETS_HAVE_TPLIFACE2
+    if ( m_scriptregistrar ) {
+        return m_scriptregistrar->registerTemplateScript(this, script);
+    }
+#else
+    Q_UNUSED(script);
+#endif
+    return 0;
+}
+
 
 #include "snippetstore.moc"
