@@ -32,6 +32,7 @@
 #include <sublime/area.h>
 #include <sublime/tooldocument.h>
 
+#include <language/duchain/topducontext.h>
 #include <language/editor/editorintegrator.h>
 #include <language/backgroundparser/backgroundparser.h>
 
@@ -57,6 +58,7 @@
 #include <KMessageBox>
 #include <KTextEditor/Document>
 #include <KTextEditor/SmartInterface>
+#include <language/duchain/duchain.h>
 
 namespace KDevelop {
 
@@ -197,11 +199,11 @@ bool CorePrivate::initialize(Core::Setup mode, const QString& session )
         }
         return false;
     }
-    // Initialize the item repository as first thing after loading the session,
+
     // TODO: Is this early enough, or should we put the loading of the session into
     // the controller construct
-    globalItemRepositoryRegistry();
-    
+    DUChain::initialize();
+
     if(!(mode & Core::NoUi)) uiController->initialize();
     languageController->initialize();
     projectController->initialize();
