@@ -166,8 +166,11 @@ public:
         {
             IPlugin* plugin = *it;
             IProjectFileManager* iface = plugin->extension<KDevelop::IProjectFileManager>();
+            const KPluginInfo info = m_core->pluginController()->pluginInfo( plugin );
+            if (info.property("X-KDevelop-Category").toString() != "Project")
+                continue;
             if( !iface || plugin == project->managerPlugin() )
-                pluginnames << m_core->pluginController()->pluginInfo( plugin ).pluginName();
+                pluginnames << info.pluginName();
         }
 
         return pluginnames;
@@ -726,11 +729,19 @@ void ProjectController::initializePluginCleanup(IProject* proj)
 
 void ProjectController::closeProject(IProject* proj_)
 {
-    if(!proj_ || d->m_projects.indexOf(proj_) == -1)
+    if (!proj_)
     {
         return;
     }
-    
+
+    // loading might have failed
+    d->m_currentlyOpening.removeAll(proj_->projectFileUrl());
+
+    if(d->m_projects.indexOf(proj_) == -1)
+    {
+        return;
+    }
+
     Project* proj = dynamic_cast<KDevelop::Project*>( proj_ );
     if( !proj ) 
     {
